@@ -1,10 +1,35 @@
-
+traceplot.default <- coda:::traceplot
 
 
 # ========================================================================
 # function for trace plot
 # ========================================================================
 
+
+setMethod("traceplot", signature(x = "mcmc.list"),
+  function (x, smooth = TRUE, col = 1:6, type = "l", ylab = "", ...) 
+{
+  args <- list(...)
+  for (j in 1:nvar(x)) {
+    xp <- as.vector(time(x))
+    yp <- if (nvar(x) > 1) 
+        x[, j, drop = TRUE]
+    else x
+    yp <- do.call("cbind", yp)
+    matplot(xp, yp, xlab = "Iterations", ylab = ylab, type = type, 
+        col = col, ...)
+    if (!is.null(varnames(x)) && is.null(list(...)$main)) 
+      title(paste("Trace of", varnames(x)[j]))
+    if (smooth) {
+      scol <- rep(col, length = nchain(x))
+      for (k in 1:nchain(x)) lines(lowess(xp, yp[, k]), 
+        col = scol[k])
+    }
+  }
+}
+)
+
+
 setMethod("traceplot", signature(x = "bugs"),
   function( x, mfrow = c( 1, 1 ), varname = NULL,
   match.head = TRUE, ask = TRUE,
